"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.contentTypes = exports.restful = exports.axiosInstance = exports.setInstanceDefaultOptions = void 0;
const qs = require("qs");
const axios_1 = require("axios");
const contentTypes = {
    json: 'application/json; charset=utf-8',
    urlencoded: 'application/x-www-form-urlencoded; charset=UTF-8'
};
exports.contentTypes = contentTypes;
// GET（SELECT）：从服务器取出资源（一项或多项）。
// POST（CREATE）：在服务器新建一个资源。
// PUT（UPDATE）：在服务器更新资源（客户端提供改变后的完整资源）。
// PATCH（UPDATE）：在服务器更新资源（客户端提供改变的属性）。
// DELETE（DELETE）：从服务器删除资源。 
const defaultOptions = {
    method: 'get',
    withCredentials: true,
    headers: {
        // headers 的键是不区分大小写的
        Accept: 'application/json',
        //'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8',
        'Content-Type': contentTypes.json
    },
    baseURL: 'api/',
    data: null
};
const axiosInstance = axios_1.default.create({
    timeout: 15000,
});
exports.axiosInstance = axiosInstance;
let instanceDefaultOptions = {};
const setInstanceDefaultOptions = (options) => {
    instanceDefaultOptions = options || {};
};
exports.setInstanceDefaultOptions = setInstanceDefaultOptions;
function callApi({ url, data = {}, options = {}, contentType = '' }) {
    if (!url) {
        const error = new Error('请传入 url');
        return Promise.reject(error);
    }
    const newOptions = Object.assign(Object.assign(Object.assign({}, defaultOptions), instanceDefaultOptions), options);
    if (contentType === 'urlencoded') {
        newOptions.headers = Object.assign(Object.assign({}, newOptions.headers), { 'Content-Type': contentTypes.urlencoded });
    }
    else if (contentType === 'json') {
        newOptions.headers = Object.assign(Object.assign({}, newOptions.headers), { Accept: 'application/json', 'Content-Type': contentTypes.json });
    }
    const { method } = newOptions;
    if (['get', 'head'].indexOf(method) === -1) {
        newOptions.data = data;
        if (data instanceof FormData) {
            newOptions.headers = {
                'x-requested-with': 'XMLHttpRequest',
                'cache-control': 'no-cache',
            };
        }
        else if (((newOptions.headers[method] || newOptions.headers)['Content-Type'] || '').indexOf('x-www-form-urlencoded') !== -1) {
            if (typeof data !== 'string') {
                newOptions.data = qs.stringify(data || {});
            }
        }
    }
    return axiosInstance(Object.assign({ url }, newOptions));
}
const restful = {
    request(config, contentType) {
        return callApi({
            url: config.url,
            options: Object.assign({ method: 'get' }, config),
            contentType
        });
    },
    get(url, params, options, contentType) {
        return callApi({
            url,
            options: Object.assign({ params, method: 'get' }, options),
            contentType
        });
    },
    post(url, data, options, contentType) {
        return callApi({ url, data, options: Object.assign({ method: 'post' }, options), contentType });
    },
    put(url, data, options, contentType) {
        return callApi({ url, data, options: Object.assign({ method: 'put' }, options), contentType });
    },
    delete(url, data, options, contentType) {
        return callApi({ url, data, options: Object.assign({ method: 'delete' }, options), contentType });
    },
    patch(url, data, options, contentType) {
        return callApi({ url, data, options: Object.assign({ method: 'patch' }, options), contentType });
    },
};
exports.restful = restful;
//# sourceMappingURL=index.js.map